summaryrefslogtreecommitdiffstats
path: root/lib/public/template.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/public/template.php')
-rw-r--r--lib/public/template.php100
1 files changed, 50 insertions, 50 deletions
diff --git a/lib/public/template.php b/lib/public/template.php
index 3b1a4ed4906..320b7c6393f 100644
--- a/lib/public/template.php
+++ b/lib/public/template.php
@@ -1,24 +1,24 @@
<?php
/**
-* ownCloud
-*
-* @author Frank Karlitschek
-* @copyright 2012 Frank Karlitschek frank@owncloud.org
-*
-* This library is free software; you can redistribute it and/or
-* modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
-* License as published by the Free Software Foundation; either
-* version 3 of the License, or any later version.
-*
-* This library is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU AFFERO GENERAL PUBLIC LICENSE for more details.
-*
-* You should have received a copy of the GNU Affero General Public
-* License along with this library. If not, see <http://www.gnu.org/licenses/>.
-*
-*/
+ * ownCloud
+ *
+ * @author Frank Karlitschek
+ * @copyright 2012 Frank Karlitschek frank@owncloud.org
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
+ * License as published by the Free Software Foundation; either
+ * version 3 of the License, or any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
/**
* Public interface of ownCloud for apps to use.
@@ -32,12 +32,12 @@ namespace OCP;
/**
- * @brief make OC_Helper::imagePath available as a simple function
- * @param $app app
- * @param $image image
- * @returns link to the image
+ * Make OC_Helper::imagePath available as a simple function
+ * @param string app
+ * @param string image
+ * @return link to the image
*
- * For further information have a look at OC_Helper::imagePath
+ * @see OC_Helper::imagePath
*/
function image_path( $app, $image ) {
return(\image_path( $app, $image ));
@@ -45,40 +45,39 @@ function image_path( $app, $image ) {
/**
- * @brief make OC_Helper::mimetypeIcon available as a simple function
- * Returns the path to the image of this file type.
- * @param $mimetype mimetype
- * @returns link to the image
+ * Make OC_Helper::mimetypeIcon available as a simple function
+ * @param string mimetype
+ * @return path to the image of this file type.
*/
function mimetype_icon( $mimetype ) {
return(\mimetype_icon( $mimetype ));
}
/**
- * @brief make preview_icon available as a simple function
- * Returns the path to the preview of the image.
- * @param $path path of file
- * @returns link to the preview
+ * Make preview_icon available as a simple function
+ * @param string path of file
+ * @return path to the preview of the image
*/
function preview_icon( $path ) {
return(\preview_icon( $path ));
}
/**
- * @brief make publicpreview_icon available as a simple function
+ * Make publicpreview_icon available as a simple function
* Returns the path to the preview of the image.
- * @param $path path of file
- * @returns link to the preview
+ * @param string path of file
+ * @param string token
+ * @return link to the preview
*/
function publicPreview_icon ( $path, $token ) {
return(\publicPreview_icon( $path, $token ));
}
/**
- * @brief make OC_Helper::humanFileSize available as a simple function
- * Makes 2048 to 2 kB.
- * @param $bytes size in bytes
- * @returns size as string
+ * Make OC_Helper::humanFileSize available as a simple function
+ * Example: 2048 to 2 kB.
+ * @param int size in bytes
+ * @return size as string
*/
function human_file_size( $bytes ) {
return(\human_file_size( $bytes ));
@@ -86,20 +85,21 @@ function human_file_size( $bytes ) {
/**
* @brief Return the relative date in relation to today. Returns something like "last hour" or "two month ago"
* @param $timestamp unix timestamp
* @returns human readable interpretation of the timestamp
*/
-function relative_modified_date($timestamp) {
- return(\relative_modified_date($timestamp));
+function relative_modified_date( $timestamp, $dateOnly = false ) {
+ return(\relative_modified_date($timestamp, null, $dateOnly));
}
/**
- * @brief DEPRECATED Return a human readable outout for a file size.
+ * Return a human readable outout for a file size.
* @deprecated human_file_size() instead
- * @param $byte size of a file in byte
- * @returns human readable interpretation of a file size
+ * @param integer size of a file in byte
+ * @return human readable interpretation of a file size
*/
function simple_file_size($bytes) {
return(\human_file_size($bytes));
@@ -107,11 +107,11 @@ function simple_file_size($bytes) {
/**
- * @brief Generate html code for an options block.
+ * Generate html code for an options block.
* @param $options the options
* @param $selected which one is selected?
- * @param $params the parameters
- * @returns html options
+ * @param array the parameters
+ * @return html options
*/
function html_select_options($options, $selected, $params=array()) {
return(\html_select_options($options, $selected, $params));
@@ -86,20 +85,21 @@ function human_file_size( $bytes ) {
/**
- * @brief Return the relative date in relation to today. Returns something like "last hour" or "two month ago"
- * @param $timestamp unix timestamp
- * @returns human readable interpretation of the timestamp
+ * Return the relative date in relation to today. Returns something like "last hour" or "two month ago"
+ * @param int unix timestamp
+ * @param boolean date only
+ * @return human readable interpretation of the timestamp
*/